++++++++++++
Future plans
++++++++++++

* add lots of device-specific classes

Non-plans
+++++++++
    
AsyncOWFS will never support

* Cached bus access. If you want to cache a value, do it in Python.

* Linked owservers (i.e. one server that forwards to another).

